==> openshift-model-monitoring-5.9.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/EmbeddedPersistentVolumeClaimFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class EmbeddedPersistentVolumeClaimFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent<A>{
  public EmbeddedPersistentVolumeClaimFluentImpl() {
  }
  public EmbeddedPersistentVolumeClaimFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder metadata;
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec spec;
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus status;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec getSpec() {
    return this.spec;
  }
  public A withSpec(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec spec) {
    this.spec=spec; return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus getStatus() {
    return this.status;
  }
  public A withStatus(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus status) {
    this.status=status; return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EmbeddedPersistentVolumeClaimFluentImpl that = (EmbeddedPersistentVolumeClaimFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder builder;
    public N and() {
      return (N) EmbeddedPersistentVolumeClaimFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}

==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/EmbeddedPersistentVolumeClaimFluentImpl.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class EmbeddedPersistentVolumeClaimFluentImpl<A extends io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent<A>{
  public EmbeddedPersistentVolumeClaimFluentImpl() {
  }
  public EmbeddedPersistentVolumeClaimFluentImpl(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaim instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder metadata;
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec spec;
  private io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus status;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata getMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata buildMetadata() {
    return this.metadata!=null?this.metadata.build():null;
  }
  public A withMetadata(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder(metadata); _visitables.get("metadata").add(this.metadata);} return (A) this;
  }
  public java.lang.Boolean hasMetadata() {
    return this.metadata != null;
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadata() {
    return new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluentImpl.MetadataNestedImpl();
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> withNewMetadataLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata item) {
    return new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluentImpl.MetadataNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder().build());
  }
  public io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<A> editOrNewMetadataLike(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec getSpec() {
    return this.spec;
  }
  public A withSpec(io.fabric8.kubernetes.api.model.PersistentVolumeClaimSpec spec) {
    this.spec=spec; return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus getStatus() {
    return this.status;
  }
  public A withStatus(io.fabric8.kubernetes.api.model.PersistentVolumeClaimStatus status) {
    this.status=status; return (A) this;
  }
  public java.lang.Boolean hasStatus() {
    return this.status != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EmbeddedPersistentVolumeClaimFluentImpl that = (EmbeddedPersistentVolumeClaimFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public class MetadataNestedImpl<N> extends io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<N>> implements io.fabric8.openshift.api.model.monitoring.v1.EmbeddedPersistentVolumeClaimFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MetadataNestedImpl(io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadata item) {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder(this);
    }
    io.fabric8.openshift.api.model.monitoring.v1.EmbeddedObjectMetadataBuilder builder;
    public N and() {
      return (N) EmbeddedPersistentVolumeClaimFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  
}
